Changelog — django-frontend 0.3.1 documentation

### Navigation

- index
- next |
- previous |
- django-frontend 0.3.1 documentation »

# Changelog

## 0.3.1

- Fixed URL to TWBS Glyphicons in bootstrap.min.css

## 0.3.0

- Updated Twitter Bootstrap to v3.0.0
- Added djfrontend_twbs_theme_css template tag
- Added bootstrap-theme.css and bootstrap-theme.min.css
- Added djfrontend_jquery_scrollto template tag
- Added jquery.scrollTo.js and jquery.scrollTo.min.js
- Removed djfrontend_twbs_glyphicons template tag
- Removed bootstrap-glyphicons.css

## 0.2.1

- Updated Twitter Bootstrap to v3.0.0 RC2

## 0.2.0

- Updated jQuery to v1.10.2 and v2.0.3
- Updated Twitter Bootstrap to v3.0.0 RC1
- Added djfrontend_twbs_glyphicons template tag
- Added cdnjs initial loading for Modernizr and jQuery DataTables
- Removed djfrontend_twbs_responsive_css template tag
- Removed bootstrap-typeahead.js

## 0.1.0

- Initial release

### Navigation

- index
- next |
- previous |
- django-frontend 0.3.1 documentation »